@@ -3,9 +3,12 @@
 #' @description Calculates abundance
 #' @param  collections Collections data retrieved from getArthroCollections()
 #' @param interval Calculation interval for abundance, accepts “collection_date”,“Biweek”,“Week”, and “Month.
+#' @param agency An optional vector for filtering agency by character code
 #' @param species An optional vector for filtering species. Species_display_name is the accepted notation.To see a list of species present in your data run unique(collections$species_display_name). If species is unspecified, the default NULL will return data for all species in data.
 #' @param trap An optional vector for filtering trap type by acronym. Trap_acronym is the is the accepted notation. Run unique(collections$trap_acronym) to see trap types present in your data. If trap is unspecified, the default NULL will return data for all trap types.
 #' @param sex An optional vector for filtering sex type. Accepts 'male', 'female',or 'other'. If sex is unspecified, the default NULL will return data for female sex.
+#' @param trapnight_min Minimum trap night restriction for calculation. Default is 1.
+#' @param trapnight_max Maximum trap night restriction for calculation. Default is no restriction.
 #' @param separate_by Separate/group the calculation by 'trap','species' or 'agency'. Default NULL does not separate.
 #' @return A dataframe of abundance calculations.
 #' @export
@@ -16,6 +19,8 @@
 #'              species = list('Cx pipiens'),
 #'              trap = list('GRVD', 'CO2'),
 #'              sex = list("female"),
+#'              trapnight_min = 1,
+#'              trapnight_max = 5,
 #'              separate_by  = "species")
 #' @export
 #' @importFrom dplyr summarise summarize filter group_by distinct_at vars arrange mutate desc bind_rows rename
@@ -34,16 +39,17 @@
 #species, trap filter the data according to abbreviated scientific name and trap acronym
 #If species, trap are left as NULL, the default assumes "All Options Selected"
 #
-getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex = "female", separate_by = NULL) {
+getAbundance <- function(collections, interval, agency = NULL, species = NULL, trap = NULL, sex = "female", trapnight_min = 1, trapnight_max=NULL,separate_by = NULL) {
 
   if (nrow(collections) <= 0) {
     stop("Collections data is empty")
   }
 
-  required_columns <- c("collection_id", "collection_date", "num_trap", "trap_nights",
+
+  required_columns <- c("collection_id", "collection_date", "agency_code","num_trap", "trap_nights",
                         "trap_problem_bit", "num_count", "sex_type", "species_display_name",
                         "trap_acronym")
-  separate_options <- c("agency","species", "trap")
+  separate_options <- c("agency","species", "trap", "subregion")
 
   if (any(!(required_columns %in% colnames(collections)))) {
     stop("Insufficient collections data provided")
@@ -52,6 +58,7 @@ getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex
     stop("Check separate_by parameters. Accepted options are 'species', 'trap', and/or 'agency'")
   }
 
+
   collections <- collections %>%
     dplyr::filter(trap_nights != 0, num_trap != 0, trap_problem_bit == FALSE)
 
@@ -59,11 +66,20 @@ getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex
     stop("Incorrect interval input. Interval accepts inputs of 'Week', 'Biweek', or 'Month'")
   }
 
+  if(is.null(trapnight_max)){
+    trapnight_max = max(collections$trap_nights)
+  }
+  if(trapnight_min<1){
+    stop("Invalid minimum trap night entered")
+  }
+
   collections$INTERVAL <- switch(interval,
                                  "Week" = as.numeric(epiweek(collections$collection_date)),
                                  "Biweek" = as.numeric(ceiling(epiweek(collections$collection_date) / 2)),
                                  "Month" = as.numeric(month(collections$collection_date)))
-
+  if (is.null(agency)) {
+    agency <- unique(collections$agency_code)
+  }
   if (is.null(species)) {
     species <- unique(collections$species_display_name)
   }
@@ -85,6 +101,11 @@ getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex
       grouping_vars <- c(grouping_vars, "agency_code")
       grouping_vars_trap <- c(grouping_vars_trap, "agency_code")
 
+    }
+    if ("subregion" %in% separate_by) {
+      grouping_vars <- c(grouping_vars, "subregion")
+      grouping_vars_trap <- c(grouping_vars_trap, "subregion")
+
     }
     if ("trap" %in% separate_by) {
       grouping_vars <- c(grouping_vars, "trap_acronym")
@@ -96,26 +117,31 @@ getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex
 
   # Calculate Counts
   collections %>%
-    dplyr::filter(species_display_name %in% species,
+    dplyr::filter(agency_code %in% agency,
+                  species_display_name %in% species,
                   trap_acronym %in% trap,
-                  sex_type %in% sex) %>%
+                  sex_type %in% sex,
+                  trap_nights>= trapnight_min,
+                  trap_nights<=trapnight_max) %>%
     dplyr::group_by(across(all_of(grouping_vars))) %>%
     dplyr::summarise(Count = sum(num_count, na.rm = TRUE),
                      Species = paste(sort(unique(species_display_name)), collapse = ", "),
                      Agency = paste(sort(unique(agency_code)), collapse = ", "),
-                     .groups = "drop") -> cts
+                     .groups = "drop") %>% as.data.frame -> cts
 
 
   # Calculate Trap Events
   collections %>%
-    dplyr::filter(trap_acronym %in% trap) %>%
+    dplyr::filter(agency_code %in% agency,
+                  trap_acronym %in% trap) %>%
     distinct_at(vars(collection_id), .keep_all = TRUE) %>%
     dplyr::group_by(across(all_of(grouping_vars_trap))) %>%
     dplyr::summarise(TrapEvents = sum(trap_nights * num_trap, na.rm = TRUE),
                      Trap = paste(sort(unique(trap_acronym)), collapse = ", "),
-                     .groups = "drop") -> tns
+                     .groups = "drop") %>% as.data.frame -> tns
+
+
 
- # names(cts)[names(cts) == 'trap_acronym'] <- 'Trap'
 
   # Merge Counts and Trap Events
   AB <- merge(cts, tns, by = grouping_vars_trap)
@@ -123,10 +149,17 @@ getAbundance <- function(collections, interval, species = NULL, trap = NULL, sex
   # Calculate Abundance
   AB$Abundance <- round(AB$Count / AB$TrapEvents, 2)
   AB <- AB %>% arrange(desc(surv_year), INTERVAL)
+  if ("subregion" %in% separate_by){
   AB  = AB %>%
+    select(Agency, surv_year, INTERVAL,subregion, Species,Count,TrapEvents, Trap, Abundance)
+
+  }
+  else{ AB  = AB %>%
     select(Agency, surv_year, INTERVAL, Species,Count,TrapEvents, Trap, Abundance)
+  }
   # Rename columns
   colnames(AB)[3] <- interval
+
   colnames(AB)[2] <- "Year"
 
   return(AB)
