@@ -5,12 +5,12 @@
 #' @param interval Calculation interval for comparison table, accepts “collection_date”,“Biweek”,“Week”, and “Month
 #' @param target_disease The disease to calculate infection rate for–i.e. “WNV”.
 #'  Disease acronyms are the accepted input. To see a list of disease acronyms, run `unique(pools$target_acronym)`
-#' @param species_separate Should the pools comparison be split by species of each pool. Default is FALSE
+#' @param separate_by Separate/group the calculation by 'trap','species' or 'agency'. Default NULL does not separate.
 #' @examples
 #' getPoolsComparisionTable(sample_pools,
 #'                          interval = "Biweek",
 #'                          target_disease = "WNV",
-#'                           species_separate = TRUE)
+#'                           separate_by = "species")
 #' @export
 #' @return Frequency table of for pools data
 #' @importFrom dplyr count
@@ -22,7 +22,7 @@
 
 #Produces a frequency table for positive and negative pools counts by year
 
-getPoolsComparisionTable = function(pools, interval, target_disease, species_separate=FALSE){
+getPoolsComparisionTable = function(pools, interval, target_disease, separate_by=NULL){
 
 
   if(nrow(pools)<=0){
@@ -49,28 +49,29 @@ collection_date, num_trap, trap_nights, num_count, sex_type, species_display_nam
                           "Week"= as.numeric(epiweek(pools$collection_date)),
                           "Biweek"= as.numeric(ceiling(epiweek(pools$collection_date)/2)),
                           "Month"= as.numeric(month(pools$collection_date)))
+  grouping_vars <- c("surv_year", "INTERVAL")
+  if (!is.null(separate_by)) {
+    if ("species" %in% separate_by) {
+      grouping_vars <- c(grouping_vars, "species_display_name")
+    }
+    if ("trap" %in% separate_by) {
+      grouping_vars <- c(grouping_vars, "trap_acronym")
+    }
+    if ("agency" %in% separate_by) {
+      grouping_vars <- c(grouping_vars, "agency_code")
+    }
+  }
+
   pools_status = pools %>%
     dplyr::filter(target_acronym==target_disease)%>%
-    group_by(surv_year, INTERVAL) %>%
+    group_by(across(all_of(grouping_vars))) %>%
     count(status_name)%>%
-    pivot_wider(id_cols = c(surv_year,INTERVAL),
+    pivot_wider(id_cols = c(grouping_vars),
                 names_from = "status_name",
                 values_from = "n",values_fill = 0)%>%
     mutate(Total = sum(Confirmed,Negative, na.rm=T))%>%
     mutate(`Percent Positive` = round((Confirmed/Total)*100,2))
 
-  if(species_separate == T){
-    pools_status = pools %>% dplyr::filter(target_acronym==target_disease)%>%
-      group_by(surv_year, species_display_name, INTERVAL) %>%
-      count(status_name)%>%
-      pivot_wider(id_cols = c(surv_year,INTERVAL, species_display_name),
-                  names_from = "status_name",
-                  values_from = "n",values_fill = 0)%>%
-      mutate(Total = sum(Confirmed,Negative, na.rm=T))%>%
-      mutate(`Percent Positive` = round((Confirmed/Total)*100, 2))
-
-  }
-
   colnames(pools_status)[1:2] = c("Year",interval)
 
   return(pools_status)
